NURTURE [ PROTEIN ] https://en.wikipedia.org/wiki/Essential_amino_acid [ COLLAGEN ] [ HISTIDINE ] LABELS: [ "AMINO ACID" ] NOTES: [] [ HISTIDINE ] LABELS: [ "AMINO ACID" ] NOTES: [] [ CARBOHYDRATES ] [ CARBOHYDRATES, BY DIFFERENCE ] [ DIETARY FIBER ] [ SUGARS, TOTAL INCLUDING NLEA ] [ SUGARS, ADDED ] [ LIPIDS ] [ FATS ] [ ESTER ] https://en.wikipedia.org/wiki/Ester [ FATTY ACID ] https://en.wikipedia.org/wiki/Fatty_acid "CARBOXYLIC ACID" WITH AN "ALIPHATIC" CHAIN [ SATURATED FATTY ACIDS ] https://en.wikipedia.org/wiki/List_of_saturated_fatty_acids [ UNSATURATED FATTY ACIDS ] https://en.wikipedia.org/wiki/List_of_unsaturated_fatty_acids [ WAXES ] [ STEROLS ] [ FAT-SOLUABLE VITAMINS ] [ MONOGLYCERIDES ] [ DIGLYCERIDES ] [ PHOSPHOLIPIDS ] [ VITAMIN A, RETINOL, RETINOIC ACID ]: https://en.wikipedia.org/wiki/Vitamin_A https://www.hsph.harvard.edu/nutritionsource/vitamin-a/ https://www.mayoclinic.org/drugs-supplements-vitamin-a/art-20365945 VITAMIN B: https://en.wikipedia.org/wiki/B_vitamins HEALTHY: [ VITAMIN B1, THIAMIN ] [ VITAMIN B2, RIBOFLAVIN ] [ VITAMIN B3 NIACIN ] [ VITAMIN B3 NICOTINAMIDE ] [ VITAMIN B3 NICOTINAMIDE RIBOSIDE ] [ VITAMIN B5, PANTOTHENIC ACID ] [ VITAMIN B6, PYRIDOXINE ] [ VITAMIN B6, PYRIDOXAL ] [ VITAMIN B6, PYRIDOXAMINE ] [ VITAMIN B7, BIOTIN ] [ VITAMIN B9, FOLATE ] [ VITAMIN B12, COBALAMINS ] https://en.wikipedia.org/wiki/B_vitamins#Related_compounds [ VITAMIN C ]